/*
 * Definitions for libwtcdb
 *
 * Copyright (C) 2010-2024, Joachim Metz <joachim.metz@gmail.com>
 *
 * Refer to AUTHORS for acknowledgements.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#if !defined( _LIBWTCDB_DEFINITIONS_H )
#define _LIBWTCDB_DEFINITIONS_H

#include <libwtcdb/types.h>

#define LIBWTCDB_VERSION		20240518

/* The version string
 */
#define LIBWTCDB_VERSION_STRING		"20240518"

/* The access flags definitions
 * bit 1        set to 1 for read access
 * bit 2        set to 1 for write access
 * bit 3-8      not used
 */
enum LIBWTCDB_ACCESS_FLAGS
{
	LIBWTCDB_ACCESS_FLAG_READ	= 0x01,
/* Reserved: not supported yet */
	LIBWTCDB_ACCESS_FLAG_WRITE	= 0x02
};

/* The file access macros
 */
#define LIBWTCDB_OPEN_READ		( LIBWTCDB_ACCESS_FLAG_READ )
/* Reserved: not supported yet */
#define LIBWTCDB_OPEN_WRITE		( LIBWTCDB_ACCESS_FLAG_WRITE )
/* Reserved: not supported yet */
#define LIBWTCDB_OPEN_READ_WRITE	( LIBWTCDB_ACCESS_FLAG_READ | LIBWTCDB_ACCESS_FLAG_WRITE )

/* The file types
 */
enum LIBWTCDB_FILE_TYPES
{
	LIBWTCDB_FILE_TYPE_CACHE	= (uint8_t) 'c',
	LIBWTCDB_FILE_TYPE_INDEX_V20	= (uint8_t) 'i',
	LIBWTCDB_FILE_TYPE_INDEX_V30	= (uint8_t) 'I'
};

#define LIBWTCDB_FILE_TYPE_INDEX	LIBWTCDB_FILE_TYPE_INDEX_V20

#endif /* !defined( _LIBWTCDB_DEFINITIONS_H ) */

